dm: treewide: Rename ..._platdata variables to just ..._plat

Try to maintain some consistency between these variables by using _plat as
a suffix for them.

Signed-off-by: Simon Glass <sjg@chromium.org>
diff --git a/arch/x86/cpu/apollolake/hostbridge.c b/arch/x86/cpu/apollolake/hostbridge.c
index 16f90a4..e4674f3 100644
--- a/arch/x86/cpu/apollolake/hostbridge.c
+++ b/arch/x86/cpu/apollolake/hostbridge.c
@@ -42,7 +42,7 @@
 };
 
 /**
  * struct apl_hostbridge_platdata - platform data for hostbridge
  *
  * @dtplat: Platform data for of-platdata
  * @early_pads: Early pad data to set up, each (pad, cfg0, cfg1)
@@ -50,7 +50,7 @@
  * @pciex_region_size: BAR length in bytes
  * @bdf: Bus/device/function of hostbridge
  */
-struct apl_hostbridge_platdata {
+struct apl_hostbridge_plat {
 #if CONFIG_IS_ENABLED(OF_PLATDATA)
 	struct dtd_intel_apl_hostbridge dtplat;
 #endif
@@ -158,7 +158,7 @@
 
 static int apl_hostbridge_early_init_pinctrl(struct udevice *dev)
 {
-	struct apl_hostbridge_platdata *plat = dev_get_plat(dev);
+	struct apl_hostbridge_plat *plat = dev_get_plat(dev);
 	struct udevice *pinctrl;
 	int ret;
 
@@ -172,7 +172,7 @@
 
 static int apl_hostbridge_early_init(struct udevice *dev)
 {
-	struct apl_hostbridge_platdata *plat = dev_get_plat(dev);
+	struct apl_hostbridge_plat *plat = dev_get_plat(dev);
 	u32 region_size;
 	ulong base;
 	u32 reg;
@@ -223,7 +223,7 @@
 
 static int apl_hostbridge_of_to_plat(struct udevice *dev)
 {
-	struct apl_hostbridge_platdata *plat = dev_get_plat(dev);
+	struct apl_hostbridge_plat *plat = dev_get_plat(dev);
 	struct udevice *pinctrl;
 	int ret;
 
@@ -403,7 +403,7 @@
 	.of_to_plat = apl_hostbridge_of_to_plat,
 	.probe		= apl_hostbridge_probe,
 	.remove		= apl_hostbridge_remove,
-	.plat_auto	= sizeof(struct apl_hostbridge_platdata),
+	.plat_auto	= sizeof(struct apl_hostbridge_plat),
 	ACPI_OPS_PTR(&apl_hostbridge_acpi_ops)
 	.flags		= DM_FLAG_OS_PREPARE,
 };
@@ -42,7 +42,7 @@
 
 /**
- * struct apl_hostbridge_platdata - platform data for hostbridge
+ * struct apl_hostbridge_plat - platform data for hostbridge
  *
  * @dtplat: Platform data for of-platdata